from setuptools import setup
setup(
    name='nester261',
    version='1.0.0',
    py_modules=['nester261'],
    author='Maruf',
    author_email='marufahamed011@gmail.com',
    url='https://github.com/Maruf261/nester',
    description='A simple printer of nested list',
    )
